pub struct SharedVmoIo;Expand description
The type corresponding to the SharedVmoIo protocol. This is a generic protocol for driver IO using shared VMOs. Drivers may compose this protocol and choose which methods to implement based on the uses of the hardware. This protocol is only intended for simple use cases.