pub struct SharedVmoIoTransmitRequest {
pub buffer: SharedVmoBuffer,
}Fields
buffer: SharedVmoBufferTrait Implementations
Sourcefn clone(&self) -> SharedVmoIoTransmitRequest
fn clone(&self) -> SharedVmoIoTransmitRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn encode_option(
this: Option<&'a SharedVmoIoTransmitRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SharedVmoIoTransmitRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SharedVmoIoTransmitRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SharedVmoIoTransmitRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourcefn encode_option(
this: Option<SharedVmoIoTransmitRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SharedVmoIoTransmitRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SharedVmoIoTransmitRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SharedVmoIoTransmitRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourcefn from_wire(wire: SharedVmoIoTransmitRequest) -> SharedVmoIoTransmitRequest
fn from_wire(wire: SharedVmoIoTransmitRequest) -> SharedVmoIoTransmitRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourcefn from_wire_ref(
wire: &SharedVmoIoTransmitRequest,
) -> SharedVmoIoTransmitRequest
fn from_wire_ref( wire: &SharedVmoIoTransmitRequest, ) -> SharedVmoIoTransmitRequest
Converts the given reference to this type.
Sourcefn cmp(&self, other: &SharedVmoIoTransmitRequest) -> Ordering
fn cmp(&self, other: &SharedVmoIoTransmitRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourcefn eq(&self, other: &SharedVmoIoTransmitRequest) -> bool
fn eq(&self, other: &SharedVmoIoTransmitRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Auto Trait Implementations