pub struct SharedVmoRight(/* private fields */);Implementations
Sourcepub const READ: SharedVmoRight
pub const READ: SharedVmoRight
The protocol implementation can read from this VMO (used for transmit requests).
Sourcepub const WRITE: SharedVmoRight
pub const WRITE: SharedVmoRight
The protocol implementation can write to this VMO (used for receive requests).
Sourcepub const fn empty() -> SharedVmoRight
pub const fn empty() -> SharedVmoRight
Get a flags value with all bits unset.
Sourcepub const fn all() -> SharedVmoRight
pub const fn all() -> SharedVmoRight
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SharedVmoRight>
pub const fn from_bits(bits: u32) -> Option<SharedVmoRight>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SharedVmoRight
pub const fn from_bits_truncate(bits: u32) -> SharedVmoRight
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SharedVmoRight
pub const fn from_bits_retain(bits: u32) -> SharedVmoRight
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SharedVmoRight>
pub fn from_name(name: &str) -> Option<SharedVmoRight>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SharedVmoRight) -> bool
pub const fn intersects(&self, other: SharedVmoRight) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SharedVmoRight) -> bool
pub const fn contains(&self, other: SharedVmoRight) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SharedVmoRight)
pub fn insert(&mut self, other: SharedVmoRight)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SharedVmoRight)
pub fn remove(&mut self, other: SharedVmoRight)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SharedVmoRight)
pub fn toggle(&mut self, other: SharedVmoRight)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SharedVmoRight, value: bool)
pub fn set(&mut self, other: SharedVmoRight, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SharedVmoRight) -> SharedVmoRight
pub const fn intersection(self, other: SharedVmoRight) -> SharedVmoRight
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SharedVmoRight) -> SharedVmoRight
pub const fn union(self, other: SharedVmoRight) -> SharedVmoRight
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SharedVmoRight) -> SharedVmoRight
pub const fn difference(self, other: SharedVmoRight) -> SharedVmoRight
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SharedVmoRight) -> SharedVmoRight
pub const fn symmetric_difference(self, other: SharedVmoRight) -> SharedVmoRight
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SharedVmoRight
pub const fn complement(self) -> SharedVmoRight
The bitwise negation (!) of the bits in self, truncating the result.
Sourcepub const fn iter(&self) -> Iter<SharedVmoRight>
pub const fn iter(&self) -> Iter<SharedVmoRight>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SharedVmoRight>
pub const fn iter_names(&self) -> IterNames<SharedVmoRight>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.