#[repr(C)]pub struct SharedVmoRegisterRegisterVmoRequest {
pub vmo_id: Uint32,
pub vmo: Range,
pub rights: SharedVmoRight,
}Expand description
The wire type corresponding to SharedVmoRegisterRegisterVmoRequest.
Fields
vmo_id: Uint32vmo: Rangerights: SharedVmoRightTrait Implementations
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoRegisterRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoRegisterRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoRegisterRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoRegisterRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn from_wire(wire: SharedVmoRegisterRegisterVmoRequest) -> Self
fn from_wire(wire: SharedVmoRegisterRegisterVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourcetype Natural = SharedVmoRegisterRegisterVmoRequest
type Natural = SharedVmoRegisterRegisterVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourcetype Narrowed<'de> = SharedVmoRegisterRegisterVmoRequest
type Narrowed<'de> = SharedVmoRegisterRegisterVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.